@@ -7,9 +7,9 @@ class Stub(Actor):
 
     def update_pressure(self, ts):
         for pipe in self.parents:
-            pipe.pressures['in'] = 0
+            pipe.pressures["in"] = 0
         for pipe in self.children:
-            pipe.pressures['out'] = 0
+            pipe.pressures["out"] = 0
 
     def __str__(self):
-        return f'Stub {self.name}'
\ No newline at end of file
+        return f"Stub {self.name}"
